Εγγραφή | OiRA

Θέματα

# Εγγραφή

## Γιατί πρέπει να εγγραφώ;

Η πρώτη ενέργεια που θα σας ζητηθεί να κάνετε όταν ξεκινήσετε την πρώτη σας εκτίμηση κινδύνου είναι να δημιουργήσετε έναν λογαριασμό OiRA –πρόκειται για μια απλή και σύντομη διαδικασία.

Η εγγραφή σάς επιτρέπει να συνδέεστε ανά πάσα στιγμή για να αποκτήσετε πρόσβαση στα δεδομένα σας, να συνεχίσετε προηγούμενες εκτιμήσεις ή να ξεκινήσετε νέες.

Η εγγραφή επιτρέπει στο σύστημα OiRA να αποθηκεύει όλες σας τις συνεδρίες, ώστε τα δεδομένα σας να είναι διαθέσιμα ανά πάσα στιγμή.

Διαβάστε την πολιτική απορρήτου που τηρούμε και το πώς χειριζόμαστε τα προσωπικά σας δεδομένα.

## Ποια είναι η διαφορά μεταξύ της εγγραφής ως χρήστη και της διενέργειας δοκιμαστικής συνεδρίας;

Η δοκιμαστική συνεδρία επιτρέπει στα ενδιαφερόμενα μέρη να συμβουλεύονται το εργαλείο προτού αποφασίσουν να εγγραφούν. Πάντως, κατά τη διάρκεια της δοκιμαστικής συνεδρίας, τα προσωπικά σας δεδομένα δεν αποθηκεύονται και δεν θα έχετε τη δυνατότητα να ανακτήσετε πληροφορίες που καταχωρίσατε σε μεταγενέστερο στάδιο. Η δοκιμαστική συνεδρία δεν σας επιτρέπει να εκτυπώσετε καμία έκθεση, ενώ η εγγραφή και δημιουργία του λογαριασμού σάς επιτρέπει να τεκμηριώσετε πλήρως την εκτίμηση κινδύνου που διενεργείτε.

## Εγγραφή για τη δημιουργία νέου λογαριασμού

Πρόκειται για την πρώτη σας επίσκεψη; Ακολουθήστε τα απλά αυτά βήματα και ξεκινήστε:

1.) Κάντε «κλικ» στο «Εγγραφή» για να δείτε το έντυπο εγγραφής.

Έντυπο εγγραφής.

2.) Εισάγετε τη διεύθυνση του ηλεκτρονικού σας ταχυδρομείου και επιλέξτε κωδικό πρόσβασης (δύο φορές)

3.) Κάντε «κλικ» στο «Επόμενο» για να δημιουργήσετε τον νέο σας λογαριασμό.

4.) Διαβάστε και αποδεχθείτε την πολιτική απορρήτου για να συνεχίσετε

Θα συνδεθείτε τώρα με το σύστημα του εργαλείου OiRA.

## Σύνδεση με υπάρχοντα λογαριασμό

Εάν έχετε ήδη εγγραφεί, εκτελέστε τις ακόλουθες ενέργειες για να αποκτήσετε πρόσβαση στον λογαριασμό σας:

1.) Επισκεφθείτε το έντυπο σύνδεσης. Κάθε φορά που επιχειρείτε να αποκτήσετε πρόσβαση στο OiRA, θα εμφανίζεται ένας σύνδεσμος που οδηγεί στο έντυπο σύνδεσης έως ότου συνδεθείτε.

Έντυπο σύνδεσης.

2.) Συμπληρώστε τη διεύθυνση του ηλεκτρονικού ταχυδρομείου σας και τον κωδικό πρόσβασής σας.

3.) Συνδεθείτε κάνοντας «κλικ» στο «Σύνδεση».

Μόλις συνδεθείτε, θα εμφανιστεί η ακόλουθη οθόνη. Από εδώ μπορείτε να ξεκινήσετε μια νέα εκτίμηση κινδύνου ή να επιστρέψετε στις εκτιμήσεις κινδύνου που έχετε ήδη ξεκινήσει.

Πίνακας.

Ξεκινήστε μια νέα εκτίμηση κινδύνου δίνοντας έναν τίτλο (π.χ. Η εταιρία μου στις 7/3/2018) ή αποκτήστε πρόσβαση σε μια από τις προηγούμενες εκτιμήσεις κινδύνου που διενεργήσατε. Όλες οι εκτιμήσεις κινδύνου που διενεργείτε αποθηκεύονται για μελλοντική χρήση, εκτός εάν επιλέξετε να τις διαγράψετε.

Scroll to top Load toolbar…
Back

## 1-registration.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More